@@ -6,7 +6,7 @@ use warnings;
 
 use Perinci::Sub::PropertyUtil qw(declare_property);
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 declare_property(
     name => 'retry',
@@ -15,7 +15,7 @@ declare_property(
         ['int' => {min=>0, default=>0}],
         ['hash*' => {keys=>{
             'n'     => ['int' => {min=>0, default=>0}],
-            'delay' => ['int' => {min=>0, default=>0}],
+            'delay' => ['int' => {min=>0, default=>0}], # XXX: use duration?
             'success_statuses'   => ['regex' => {default=>'^(2..|304)$'}],
             'fatal_statuses'     => 'regex',
             'non_fatal_statuses' => 'regex',
@@ -132,7 +132,7 @@ Perinci::Sub::Property::retry - Specify automatic retry
 
 =head1 VERSION
 
-version 0.08
+This document describes version 0.09 of Perinci::Sub::Property::retry (from Perl distribution Perinci-Sub-Property-retry), released on 2016-03-09.
 
 =head1 SYNOPSIS
 
@@ -196,10 +196,6 @@ the eval block.
 It also pass a special argument to the function C<-retries> so that function can
 be aware about retries.
 
-=head1 SEE ALSO
-
-L<Perinci>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-Property-retry>.
@@ -216,13 +212,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci>
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
